@@ -5,6 +5,7 @@ import click
 from src.config import global_config, config_manager
 from src.config.global_config import compile_ip, compile_host_mame
 from src.local import http_server, pc_info, net_manager
+from src.script import script_manager
 from src.server import server_config
 
 
@@ -35,6 +36,9 @@ def print_version(ctx, param, value):
     version_info = """
     作者:ming 
     仅适用linux 其他平台兼容性不做保证
+    启用自动补全:
+    bash: eval "$(_M_COMPLETE=source m)"
+    zsh: eval "$(_M_COMPLETE=source_zsh m)"
     jiuming-tools Version {}""".format(global_config.version)
     click.echo(version_info)
     ctx.exit()
@@ -98,18 +102,20 @@ def local_pc_info():
 
 @local.command('http', help='根据指定文件夹开启临时http服务器')
 @click.option('--d', '-d', type=click.Path(exists=True), default='.', nargs=1, help='指定静态文件目录,默认为.')
-@click.option('--port', '-p', default=80, type=int, nargs=1, help='指定服务端口,默认为80')
+@click.option('--port', '-p', default=20000, type=int, nargs=1, help='指定服务端口,默认为20000')
 @click.option('--host', '-h', default='0.0.0.0', callback=validate_ip_or_host_name_type, type=str, nargs=1,
               help='指定服务监听地址,默认为0.0.0.0')
 def local_tmp_http(d, port, host):
     http_server.http_server(d, port, host)
 
 
-@local.command('net-test', help='测试服务器是否可以打开socket')
+@local.command('socket-test', help='测试服务器是否可以打开socket')
 @click.option('--host', '-h', type=str, prompt='请输入服务器地址', callback=validate_ip_or_host_name_type, help='服务器地址')
 @click.option('--port', '-p', type=int, default=80, help='探测端口号(默认为80)')
 def net_test(host, port):
     net_manager.net_test(host, port)
+
+
 # ----------------------------------- tools config manager  -----------------------------------------------------------
 
 config_remark = """
@@ -148,8 +154,9 @@ def config_pull():
 
 
 @config.command('push', help='同步配置本地到远程仓库')
-def config_push():
-    config_manager.push()
+@click.option('--remark', '-r', type=str, help='推送备注')
+def config_push(remark):
+    config_manager.push(remark)
 
 
 @config.command('clone', help='clone配置到本地')
@@ -157,11 +164,46 @@ def config_clone():
     config_manager.clone()
 
 
+# ----------------------------------- tools config manager  -----------------------------------------------------------
+# linux 各种脚本管理   shell 、py 等脚本
 
 
+@cli.group(help='管理常用linux的脚本')
+def script():
+    pass
 
 
+@script.command('remove', help='删除脚本')
+@click.option('--name', '-n', prompt='脚本名称')
+def script_remove(name):
+    script_manager.script_remove(name)
 
-# ming 函数
+
+@script.command('create', help='创建脚本')
+@click.option('--type', '-t', prompt='脚本类型(执行引擎名称)')
+@click.option('--name', '-n', prompt='脚本名称')
+@click.option('--remark', '-r', prompt='备注描述')
+def script_create(type, name, remark):
+    script_manager.script_create(type, name, remark)
+
+
+@script.command('details', help='查看脚本详情')
+@click.option('--name', '-n', prompt='脚本名称')
+def script_details(name):
+    script_manager.script_details(name)
+
+
+@script.command('list', help='列出当前脚本')
+def script_list():
+    script_manager.script_list()
+
+
+@script.command('exec', help='执行脚本')
+@click.option('--name', '-n', prompt='脚本名称')
+def script_exec(name):
+    script_manager.script_exec(name)
+
+
+# main 函数
 if __name__ == '__main__':
     cli()
